==> kubernetes-model-autoscaling-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v1/CrossVersionObjectReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CrossVersionObjectReferenceBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference,io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceBuilder>{
  public CrossVersionObjectReferenceBuilder() {
    this(false);
  }
  public CrossVersionObjectReferenceBuilder(java.lang.Boolean validationEnabled) {
    this(new CrossVersionObjectReference(), validationEnabled);
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CrossVersionObjectReference(), validationEnabled);
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference instance) {
    this(fluent, instance, false);
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference instance) {
    this(instance,false);
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference build() {
    CrossVersionObjectReference buildable = new CrossVersionObjectReference(fluent.getApiVersion(),fluent.getKind(),fluent.getName());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CrossVersionObjectReferenceBuilder that = (CrossVersionObjectReferenceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-autoscaling-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v1/CrossVersionObjectReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CrossVersionObjectReferenceBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference,io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceBuilder>{
  public CrossVersionObjectReferenceBuilder() {
    this(false);
  }
  public CrossVersionObjectReferenceBuilder(java.lang.Boolean validationEnabled) {
    this(new CrossVersionObjectReference(), validationEnabled);
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CrossVersionObjectReference(), validationEnabled);
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference instance) {
    this(fluent, instance, false);
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference instance) {
    this(instance,false);
  }
  public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference build() {
    CrossVersionObjectReference buildable = new CrossVersionObjectReference(fluent.getApiVersion(),fluent.getKind(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CrossVersionObjectReferenceBuilder that = (CrossVersionObjectReferenceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
